==> janis-pipelines.bioinformatics-0.7.1.tar.gz: janis-pipelines.bioinformatics-0.7.1/janis_bioinformatics/tools/variantcallers/gatk/gatkgermline_variants_4_1_3.py <==
from datetime import date

from janis_core import String
from janis_bioinformatics.tools import gatk4
from janis_bioinformatics.data_types import FastaWithDict, BamBai, VcfTabix, Bed
from janis_bioinformatics.tools import BioinformaticsWorkflow
from janis_bioinformatics.tools.common import SplitMultiAllele


class GatkGermlineVariantCaller_4_1_3(BioinformaticsWorkflow):
    def id(self):
        return "GATK4_GermlineVariantCaller"

    def friendly_name(self):
        return "GATK4 Germline Variant Caller"

    @staticmethod
    def tool_provider():
        return "Variant Callers"

    def bind_metadata(self):
        self.metadata.version = "4.1.3.0"
        self.metadata.dateCreated = date(2019, 9, 1)
        self.metadata.dateUpdated = date(2019, 9, 13)

        self.metadata.contributors = ["Michael Franklin"]
        self.metadata.keywords = ["variants", "gatk", "gatk4", "variant caller"]
        self.metadata.documentation = """
        This is a VariantCaller based on the GATK Best Practice pipelines. It uses the GATK4 toolkit, specifically 4.0.12.0.

        It has the following steps:

        1. BaseRecalibrator
        2. ApplyBQSR
        3. HaplotypeCaller
        4. SplitMultiAllele
                """.strip()

    def constructor(self):

        self.input("bam", BamBai)
        self.input(
            "intervals",
            Bed(optional=True),
            doc="This optional interval supports processing by regions. If this input resolves "
            "to null, then GATK will process the whole genome per each tool's spec",
        )

        self.input("reference", FastaWithDict)

        self.input("snps_dbsnp", VcfTabix)
        self.input("snps_1000gp", VcfTabix)
        self.input("knownIndels", VcfTabix)
        self.input("millsIndels", VcfTabix)

        self.step(
            "splitBams",
            gatk4.Gatk4SplitReads_4_1_3(bam=self.bam, intervals=self.intervals),
        )

        self.step(
            "baseRecalibrator",
            gatk4.Gatk4BaseRecalibrator_4_1_3(
                bam=self.splitBams,
                intervals=self.intervals,
                reference=self.reference,
                knownSites=[
                    self.snps_dbsnp,
                    self.snps_1000gp,
                    self.knownIndels,
                    self.millsIndels,
                ],
            ),
        )
        self.step(
            "applyBQSR",
            gatk4.Gatk4ApplyBqsr_4_1_3(
                bam=self.splitBams,
                intervals=self.intervals,
                recalFile=self.baseRecalibrator.out,
                reference=self.reference,
            ),
        )
        self.step(
            "haplotypeCaller",
            gatk4.Gatk4HaplotypeCaller_4_1_3(
                inputRead=self.applyBQSR,
                intervals=self.intervals,
                reference=self.reference,
                dbsnp=self.snps_dbsnp,
            ),
        )
        self.step(
            "splitMultiAllele",
            SplitMultiAllele(reference=self.reference, vcf=self.haplotypeCaller),
        )

        self.output("out", source=self.splitMultiAllele)


if __name__ == "__main__":
    vc = GatkGermlineVariantCaller_4_1_3().translate("wdl", to_console=True)
    # print(vc.translate("cwl"))

==> janis-pipelines.bioinformatics-0.8.0.tar.gz: janis-pipelines.bioinformatics-0.8.0/janis_bioinformatics/tools/variantcallers/gatk/gatkgermline_variants_4_1_3.py <==
from datetime import date

from janis_core import String
from janis_bioinformatics.tools import gatk4
from janis_bioinformatics.data_types import FastaWithDict, BamBai, VcfTabix, Bed
from janis_bioinformatics.tools import BioinformaticsWorkflow
from janis_bioinformatics.tools.common import SplitMultiAllele


class GatkGermlineVariantCaller_4_1_3(BioinformaticsWorkflow):
    def id(self):
        return "GATK4_GermlineVariantCaller"

    def friendly_name(self):
        return "GATK4 Germline Variant Caller"

    def tool_provider(self):
        return "Variant Callers"

    def bind_metadata(self):
        self.metadata.version = "4.1.3.0"
        self.metadata.dateCreated = date(2019, 9, 1)
        self.metadata.dateUpdated = date(2019, 9, 13)

        self.metadata.contributors = ["Michael Franklin"]
        self.metadata.keywords = ["variants", "gatk", "gatk4", "variant caller"]
        self.metadata.documentation = """
        This is a VariantCaller based on the GATK Best Practice pipelines. It uses the GATK4 toolkit, specifically 4.0.12.0.

        It has the following steps:

        1. BaseRecalibrator
        2. ApplyBQSR
        3. HaplotypeCaller
        4. SplitMultiAllele
                """.strip()

    def constructor(self):

        self.input("bam", BamBai)
        self.input(
            "intervals",
            Bed(optional=True),
            doc="This optional interval supports processing by regions. If this input resolves "
            "to null, then GATK will process the whole genome per each tool's spec",
        )

        self.input("reference", FastaWithDict)

        self.input("snps_dbsnp", VcfTabix)
        self.input("snps_1000gp", VcfTabix)
        self.input("knownIndels", VcfTabix)
        self.input("millsIndels", VcfTabix)

        self.step(
            "splitBams",
            gatk4.Gatk4SplitReads_4_1_3(bam=self.bam, intervals=self.intervals),
        )

        self.step(
            "baseRecalibrator",
            gatk4.Gatk4BaseRecalibrator_4_1_3(
                bam=self.splitBams,
                intervals=self.intervals,
                reference=self.reference,
                knownSites=[
                    self.snps_dbsnp,
                    self.snps_1000gp,
                    self.knownIndels,
                    self.millsIndels,
                ],
            ),
        )
        self.step(
            "applyBQSR",
            gatk4.Gatk4ApplyBqsr_4_1_3(
                bam=self.splitBams,
                intervals=self.intervals,
                recalFile=self.baseRecalibrator.out,
                reference=self.reference,
            ),
        )
        self.step(
            "haplotypeCaller",
            gatk4.Gatk4HaplotypeCaller_4_1_3(
                inputRead=self.applyBQSR,
                intervals=self.intervals,
                reference=self.reference,
                dbsnp=self.snps_dbsnp,
            ),
        )
        self.step(
            "splitMultiAllele",
            SplitMultiAllele(reference=self.reference, vcf=self.haplotypeCaller),
        )

        self.output("out", source=self.splitMultiAllele)


if __name__ == "__main__":
    vc = GatkGermlineVariantCaller_4_1_3().translate("wdl", to_console=True)
    # print(vc.translate("cwl"))
